@@ -41,7 +41,7 @@
  *
  */
 
-/* $Id: deliver.c,v 1.169.2.10 2005/05/04 19:26:16 ken3 Exp $ */
+/* $Id: deliver.c,v 1.176 2007/02/05 18:41:46 jeaton Exp $ */
 
 #include <config.h>
 
@@ -70,8 +70,11 @@
 #include "exitcodes.h"
 #include "imap_err.h"
 #include "xmalloc.h"
+#include "xstrlcpy.h"
+#include "xstrlcat.h"
 #include "lmtpengine.h"
 #include "prot.h"
+#include "proxy.h"
 #include "version.h"
 
 /* config.c stuff */
