@@ -38,7 +38,7 @@
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * $Id: delivered_prune.c,v 1.2 2006/11/30 17:11:17 murch Exp $
+ * $Id: delivered_prune.c,v 1.3 2007/03/30 18:40:20 murch Exp $
  */
 
 #include <config.h>
@@ -83,7 +83,9 @@ int main(int argc, char *argv[])
     int opt, r = 0, expire_days = 0;
     char *alt_config = NULL;
 
-    if (geteuid() == 0) fatal("must run as the Cyrus user", EC_USAGE);
+    if ((geteuid()) == 0 && (become_cyrus() != 0)) {
+	fatal("must run as the Cyrus user", EC_USAGE);
+    }
 
     while ((opt = getopt(argc, argv, "C:E:")) != EOF) {
 	switch (opt) {
