@@ -39,7 +39,7 @@
  *
  */
 
-/* $Id: duplicate.c,v 1.42 2006/11/30 17:11:17 murch Exp $ */
+/* $Id: duplicate.c,v 1.44 2007/08/15 17:20:55 murch Exp $ */
 
 #include <config.h>
 
@@ -105,7 +105,7 @@ int duplicate_init(char *fname, int myflags __attribute__((unused)))
 	    strcat(fname, FNAME_DELIVERDB);
 	}
 
-	r = DB->open(fname, CYRUSDB_CREATE, &dupdb);
+	r = (DB->open)(fname, CYRUSDB_CREATE, &dupdb);
 	if (r != 0)
 	    syslog(LOG_ERR, "DBERROR: opening %s: %s", fname,
 		   cyrusdb_strerror(r));
@@ -164,17 +164,8 @@ time_t duplicate_check(char *id, int idlen, const char *to, int tolen)
 
 void duplicate_log(char *msgid, const char *name, char *action)
 {
-    if (strlen(msgid) < 80) {
-	char pretty[160];
-
-	beautify_copy(pretty, msgid);
-	syslog(LOG_INFO, "dupelim: eliminated duplicate message to %s id %s (%s)",
-	       name, msgid, action);
-    }
-    else {
-	syslog(LOG_INFO, "dupelim: eliminated duplicate message to %s (%s)",
-	       name, action);
-    }	
+    syslog(LOG_INFO, "dupelim: eliminated duplicate message to %s id %s (%s)",
+	   name, msgid, action);
 }
 
 void duplicate_mark(char *id, int idlen, const char *to, int tolen, time_t mark,
@@ -404,7 +395,7 @@ int duplicate_done(void)
     int r = 0;
 
     if (duplicate_dbopen) {
-	r = DB->close(dupdb);
+	r = (DB->close)(dupdb);
 	if (r) {
 	    syslog(LOG_ERR, "DBERROR: error closing deliverdb: %s",
 		   cyrusdb_strerror(r));
