@@ -39,7 +39,7 @@
  *
  */
 
-/* $Id: global.c,v 1.21 2007/02/05 18:41:46 jeaton Exp $ */
+/* $Id: global.c,v 1.23 2007/03/30 18:51:00 murch Exp $ */
 
 #include <config.h>
 
@@ -83,8 +83,9 @@ static enum {
 
 static int cyrus_init_nodb = 0;
 
-int config_implicitrights;        /* "lca" */
-unsigned long config_metapartition_files;    /* 0 */
+int config_fulldirhash;				/* 0 */
+int config_implicitrights;			/* "lca" */
+unsigned long config_metapartition_files;	/* 0 */
 struct cyrusdb_backend *config_mboxlist_db;
 struct cyrusdb_backend *config_quota_db;
 struct cyrusdb_backend *config_subscription_db;
@@ -161,6 +162,8 @@ int cyrus_init(const char *alt_config, const char *ident, unsigned flags)
     }
     umask(umaskval);
 
+    config_fulldirhash = config_getswitch(IMAPOPT_FULLDIRHASH);
+
     /* look up and canonify the implicit rights of mailbox owners */
     config_implicitrights =
 	cyrus_acl_strtomask(config_getstring(IMAPOPT_IMPLICIT_OWNER_RIGHTS));
@@ -310,7 +313,9 @@ sasl_security_properties_t *mysasl_secprops(int flags)
 				/* maximum allowable security strength */
 
     ret.security_flags = flags;
-    /* ret.security_flags |= SASL_SEC_NOPLAINTEXT; */
+    if (!config_getswitch(IMAPOPT_ALLOWPLAINTEXT)) {
+	ret.security_flags |= SASL_SEC_NOPLAINTEXT;
+    }
     if (!config_getswitch(IMAPOPT_ALLOWANONYMOUSLOGIN)) {
 	ret.security_flags |= SASL_SEC_NOANONYMOUS;
     }
