@@ -1,6 +1,6 @@
 /* lmtpd.c -- Program to deliver mail to a mailbox
  *
- * $Id: lmtpd.c,v 1.147 2007/02/05 18:41:47 jeaton Exp $
+ * $Id: lmtpd.c,v 1.151 2007/07/18 18:11:55 murch Exp $
  * Copyright (c) 1998-2003 Carnegie Mellon University.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -485,8 +485,9 @@ int deliver_mailbox(FILE *f,
 
     r = append_setup(&as, mailboxname, MAILBOX_FORMAT_NORMAL,
 		     authuser, authstate, acloverride ? 0 : ACL_POST, 
-		     quotaoverride ? -1 :
-		     config_getswitch(IMAPOPT_LMTP_STRICT_QUOTA) ? size : 0);
+		     quotaoverride ? (long) -1 :
+		     config_getswitch(IMAPOPT_LMTP_STRICT_QUOTA) ?
+		     (long) size : 0);
 
     if (!r && !content->body) {
 	/* parse the message body if we haven't already,
@@ -1106,7 +1107,7 @@ FILE *spoolfile(message_data_t *msgdata)
 
     if (!f) {
 	/* we only have remote mailboxes, so use a tempfile */
-	int fd = create_tempfile();
+	int fd = create_tempfile(config_getstring(IMAPOPT_TEMP_PATH));
 
 	if (fd != -1) f = fdopen(fd, "w+");
     }
