@@ -1,5 +1,5 @@
 /* mbdump.c -- Mailbox dump routines
- * $Id: mbdump.c,v 1.33 2007/02/05 18:41:47 jeaton Exp $
+ * $Id: mbdump.c,v 1.35 2007/03/27 19:53:09 murch Exp $
  * Copyright (c) 1998-2003 Carnegie Mellon University.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -405,20 +405,21 @@ int dump_mailbox(const char *tag, const char *mbname, const char *mbpath,
 		*p = '\0'; /* separate domain!mboxname */
 		snprintf(sieve_path, sizeof(sieve_path), "%s%s%c/%s/%c/%s",
 			 config_getstring(IMAPOPT_SIEVEDIR),
-			 FNAME_DOMAINDIR, (char) dir_hash_c(mbname), mbname, 
-			 (char) dir_hash_c(p+6), p+6); /* unqualified userid */
+			 FNAME_DOMAINDIR,
+			 (char) dir_hash_c(mbname, config_fulldirhash), mbname, 
+			 (char) dir_hash_c(p+6, config_fulldirhash), p+6); /* unqualified userid */
 		*p = '!'; /* reassemble domain!mboxname */
 	    }
 	    else {
 		snprintf(sieve_path, sizeof(sieve_path), "%s/%c/%s",
 			 config_getstring(IMAPOPT_SIEVEDIR),
-			 (char) dir_hash_c(userid), userid);
+			 (char) dir_hash_c(userid, config_fulldirhash), userid);
 	    }
 	    mbdir = opendir(sieve_path);
 
 	    if (!mbdir) {
 		syslog(LOG_ERR,
-		       "could not dump sieve scripts in %s: %m)", mbpath);
+		       "could not dump sieve scripts in %s: %m)", sieve_path);
 	    } else {
 		char tag_fname[2048];
 	    
@@ -439,6 +440,10 @@ int dump_mailbox(const char *tag, const char *mbname, const char *mbpath,
 				     "SIEVE-%s", next->d_name);
 			}
 
+			/* construct path/filename */
+			snprintf(filename, sizeof(filename), "%s/%s",
+				 sieve_path, next->d_name);
+
 			/* dump file */
 			r = dump_file(0, !tag, pin, pout, filename, tag_fname);
 			if (r) goto done;
@@ -499,14 +504,15 @@ int undump_mailbox(const char *mbname, const char *mbpath,
 		*p = '\0'; /* separate domain!mboxname */
 		snprintf(sieve_path, sizeof(sieve_path), "%s%s%c/%s/%c/%s",
 			 config_getstring(IMAPOPT_SIEVEDIR),
-			 FNAME_DOMAINDIR, (char) dir_hash_c(mbname), mbname, 
-			 (char) dir_hash_c(p+6), p+6); /* unqualified userid */
+			 FNAME_DOMAINDIR,
+			 (char) dir_hash_c(mbname, config_fulldirhash), mbname, 
+			 (char) dir_hash_c(p+6, config_fulldirhash), p+6); /* unqualified userid */
 		*p = '!'; /* reassemble domain!mboxname */
 	    }
 	    else {
 		snprintf(sieve_path, sizeof(sieve_path), "%s/%c/%s",
 			 config_getstring(IMAPOPT_SIEVEDIR),
-			 (char) dir_hash_c(userid), userid);
+			 (char) dir_hash_c(userid, config_fulldirhash), userid);
 	    }
 	}
     }
