@@ -1,6 +1,6 @@
 /* mupdate-client.c -- cyrus murder database clients
  *
- * $Id: mupdate-client.c,v 1.38.2.12 2006/03/15 18:56:30 murch Exp $
+ * $Id: mupdate-client.c,v 1.49 2007/02/05 18:41:47 jeaton Exp $
  * Copyright (c) 1998-2003 Carnegie Mellon University.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -76,6 +76,8 @@
 #include "prot.h"
 #include "protocol.h"
 #include "xmalloc.h"
+#include "xstrlcpy.h"
+#include "xstrlcat.h"
 
 const char service_name[] = "mupdate";
 
