@@ -1,6 +1,6 @@
 /* mupdate.c -- cyrus murder database master 
  *
- * $Id: mupdate.c,v 1.94 2007/01/31 14:10:05 murch Exp $
+ * $Id: mupdate.c,v 1.97 2007/06/08 14:06:43 murch Exp $
  * Copyright (c) 1998-2003 Carnegie Mellon University.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -252,7 +252,6 @@ static struct conn *conn_new(int fd)
     int r;    
     int haveaddr = 0;
     int salen;
-    int secflags;
     char hbuf[NI_MAXHOST];
     int niflags;
 
@@ -337,11 +336,7 @@ static struct conn *conn_new(int fd)
     }
 
     /* set my allowable security properties */
-    secflags = SASL_SEC_NOANONYMOUS;
-    if (!config_getswitch(IMAPOPT_ALLOWPLAINTEXT)) {
-	secflags |= SASL_SEC_NOPLAINTEXT;
-    }
-    sasl_setprop(C->saslconn, SASL_SEC_PROPS, mysasl_secprops(secflags));
+    sasl_setprop(C->saslconn, SASL_SEC_PROPS, mysasl_secprops(SASL_SEC_NOANONYMOUS));
 
     /* Clear Buffers */
     memset(&(C->tag), 0, sizeof(struct buf));
@@ -1999,7 +1994,7 @@ void shut_down(int code)
 /* Reset the given sasl_conn_t to a sane state */
 static int reset_saslconn(struct conn *c)
 {
-    int ret, secflags;
+    int ret;
     sasl_security_properties_t *secprops = NULL;
 
     sasl_dispose(&c->saslconn);
@@ -2019,11 +2014,7 @@ static int reset_saslconn(struct conn *c)
                           c->saslprops.iplocalport);
     if(ret != SASL_OK) return ret;
     
-    secflags = SASL_SEC_NOANONYMOUS;
-    if (!config_getswitch(IMAPOPT_ALLOWPLAINTEXT)) {
-	secflags |= SASL_SEC_NOPLAINTEXT;
-    }
-    secprops = mysasl_secprops(secflags);
+    secprops = mysasl_secprops(SASL_SEC_NOANONYMOUS);
     ret = sasl_setprop(c->saslconn, SASL_SEC_PROPS, secprops);
     if(ret != SASL_OK) return ret;
     /* end of service_main initialization excepting SSF */
@@ -2244,6 +2235,7 @@ int mupdate_synchronize(mupdate_handle *handle)
     struct mpool *pool;
     struct sync_rock rock;
     char pattern[] = { '*', '\0' };
+    struct txn *tid = NULL;
     int ret = 0;    
 
     if(!handle || !handle->saslcompleted) return 1;
@@ -2306,21 +2298,24 @@ int mupdate_synchronize(mupdate_handle *handle)
 		mboxlist_insertremote(r->mailbox, 
 				     (r->t == SET_RESERVE ?
 				        MBTYPE_RESERVE : 0),
-				      r->server, r->acl, NULL);
+				      r->server, r->acl, &tid);
 	    }
 	    /* Okay, dump these two */
 	    local_boxes.head = l->next;
 	    remote_boxes.head = r->next;
 	} else if (ret < 0) {
 	    /* Local without corresponding remote, delete it */
-	    mboxlist_deletemailbox(l->mailbox, 1, "", NULL, 0, 0, 0);
+	    if (config_mupdate_config != IMAP_ENUM_MUPDATE_CONFIG_UNIFIED) {
+		/* But not for a unified configuration */
+		mboxlist_deleteremote(l->mailbox, &tid);
+	    }
 	    local_boxes.head = l->next;
 	} else /* (ret > 0) */ {
 	    /* Remote without corresponding local, insert it */
 	    mboxlist_insertremote(r->mailbox, 
 				  (r->t == SET_RESERVE ?
 				   MBTYPE_RESERVE : 0),
-				  r->server, r->acl, NULL);
+				  r->server, r->acl, &tid);
 	    remote_boxes.head = r->next;
 	}
     }
@@ -2328,7 +2323,10 @@ int mupdate_synchronize(mupdate_handle *handle)
     if(l && !r) {
 	/* we have more deletes to do */
 	while(l) {
-	    mboxlist_deletemailbox(l->mailbox, 1, "", NULL, 0, 0, 0);
+	    if (config_mupdate_config != IMAP_ENUM_MUPDATE_CONFIG_UNIFIED) {
+		/* But not for a unified configuration */
+		mboxlist_deleteremote(l->mailbox, &tid);
+	    }
 	    local_boxes.head = l->next;
 	    l = local_boxes.head;
 	}
@@ -2338,12 +2336,14 @@ int mupdate_synchronize(mupdate_handle *handle)
 	    mboxlist_insertremote(r->mailbox, 
 				  (r->t == SET_RESERVE ?
 				   MBTYPE_RESERVE : 0),
-				  r->server, r->acl, NULL);
+				  r->server, r->acl, &tid);
 	    remote_boxes.head = r->next;
 	    r = remote_boxes.head;
 	}
     }
 
+    if (tid) mboxlist_commit(tid);
+
     /* All up to date! */
     syslog(LOG_NOTICE, "mailbox list synchronization complete");
 
