@@ -39,7 +39,7 @@
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
-/* $Id: reconstruct.c,v 1.90 2007/02/05 18:41:48 jeaton Exp $ */
+/* $Id: reconstruct.c,v 1.93 2007/04/03 13:01:12 murch Exp $ */
 
 #include <config.h>
 
@@ -150,7 +150,9 @@ int main(int argc, char **argv)
 
     memset(&head, 0, sizeof(head));
 
-    if (geteuid() == 0) fatal("must run as the Cyrus user", EC_USAGE);
+    if ((geteuid()) == 0 && (become_cyrus() != 0)) {
+	fatal("must run as the Cyrus user", EC_USAGE);
+    }
 
     /* Ensure we're up-to-date on the index file format */
     assert(INDEX_HEADER_SIZE == (OFFSET_SPARE4+4));
@@ -577,13 +579,12 @@ reconstruct_expunge (char * path, struct mailbox * mailbox,
 	    free(expuid);
 	    return IMAP_IOERROR;
    	}
-	unsigned msgno;
-	const char *p = index_base + start_offset;
 
 	/* 
 	* verify the message files exist - 
 	* optionally deleting message files 
 	*/
+	p = index_base + start_offset;
 	for (msgno = 1; msgno <= exists; msgno++, p += record_size) {
 	    unsigned long fileuid = ntohl(*((bit32 *)(p + OFFSET_UID)));
 
@@ -1073,7 +1074,7 @@ int reconstruct(char *name, struct discovered *found)
     *((bit32 *)(buf+OFFSET_MAILBOX_OPTIONS)) = htonl(mailbox.options);
     *((bit32 *)(buf+OFFSET_LEAKED_CACHE)) = htonl(0);
 #ifdef HAVE_LONG_LONG_INT
-    *((bit64 *)(buf+OFFSET_HIGHESTMODSEQ_64)) = htonll(mailbox.highestmodseq);
+    align_htonll(buf+OFFSET_HIGHESTMODSEQ_64, mailbox.highestmodseq);
 #else
     /* zero the unused 32bits */
     *((bit32 *)(buf+OFFSET_HIGHESTMODSEQ_64)) = htonl(0);
