@@ -41,7 +41,7 @@
  * Original version written by David Carter <dpc22@cam.ac.uk>
  * Rewritten and integrated into Cyrus by Ken Murchison <ken@oceana.com>
  *
- * $Id: sync_server.c,v 1.2 2006/11/30 17:11:20 murch Exp $
+ * $Id: sync_server.c,v 1.7 2007/08/01 19:19:03 murch Exp $
  */
 
 #include <config.h>
@@ -65,6 +65,7 @@
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #include <ctype.h>
+#include <utime.h>
 
 #include <sasl/sasl.h>
 #include <sasl/saslutil.h>
@@ -123,7 +124,7 @@ void printastring(const char *s __attribute__((unused)))
 static SSL *tls_conn;
 #endif /* HAVE_SSL */
 
-sasl_conn_t *sync_saslconn; /* the sasl connection context */
+sasl_conn_t *sync_saslconn = NULL; /* the sasl connection context */
 
 char *sync_userid = 0;
 struct namespace sync_namespace;
@@ -339,14 +340,17 @@ static void dobanner(void)
     const char *mechlist;
     unsigned int mechcount;
 
-    if (sasl_listmech(sync_saslconn, NULL,
-		      "* SASL ", " ", "\r\n",
-		      &mechlist, NULL, &mechcount) == SASL_OK && mechcount > 0) {
-	prot_printf(sync_out, "%s", mechlist);
-    }
+    if (!sync_userid) {
+	if (sasl_listmech(sync_saslconn, NULL,
+			  "* SASL ", " ", "\r\n",
+			  &mechlist, NULL, &mechcount) == SASL_OK
+	    && mechcount > 0) {
+	    prot_printf(sync_out, "%s", mechlist);
+	}
 
-    if (tls_enabled() && !sync_starttls_done) {
-	prot_printf(sync_out, "* STARTTLS\r\n");
+	if (tls_enabled() && !sync_starttls_done) {
+	    prot_printf(sync_out, "* STARTTLS\r\n");
+	}
     }
 
     prot_printf(sync_out,
@@ -403,28 +407,33 @@ int service_main(int argc __attribute__((unused)),
 	if (getsockname(0, (struct sockaddr *)&sync_localaddr, &salen) == 0) {
 	    sync_haveaddr = 1;
 	}
-    }
 
-    /* other params should be filled in */
-    if (sasl_server_new("csync", config_servername, NULL, NULL, NULL,
-			NULL, 0, &sync_saslconn) != SASL_OK)
-	fatal("SASL failed initializing: sasl_server_new()",EC_TEMPFAIL); 
+	/* other params should be filled in */
+	if (sasl_server_new("csync", config_servername, NULL, NULL, NULL,
+			    NULL, 0, &sync_saslconn) != SASL_OK)
+	    fatal("SASL failed initializing: sasl_server_new()",EC_TEMPFAIL); 
 
-    /* will always return something valid */
-    secprops = mysasl_secprops(SASL_SEC_NOPLAINTEXT);
-    sasl_setprop(sync_saslconn, SASL_SEC_PROPS, secprops);
-    sasl_setprop(sync_saslconn, SASL_SSF_EXTERNAL, &extprops_ssf);
+	/* will always return something valid */
+	secprops = mysasl_secprops(SASL_SEC_NOANONYMOUS);
+	sasl_setprop(sync_saslconn, SASL_SEC_PROPS, secprops);
+	sasl_setprop(sync_saslconn, SASL_SSF_EXTERNAL, &extprops_ssf);
     
-    if(iptostring((struct sockaddr *)&sync_localaddr, salen,
-		  localip, 60) == 0) {
-	sasl_setprop(sync_saslconn, SASL_IPLOCALPORT, localip);
-	saslprops.iplocalport = xstrdup(localip);
-    }
+	if(iptostring((struct sockaddr *)&sync_localaddr, salen,
+		      localip, 60) == 0) {
+	    sasl_setprop(sync_saslconn, SASL_IPLOCALPORT, localip);
+	    saslprops.iplocalport = xstrdup(localip);
+	}
     
-    if(iptostring((struct sockaddr *)&sync_remoteaddr, salen,
-		  remoteip, 60) == 0) {
-	sasl_setprop(sync_saslconn, SASL_IPREMOTEPORT, remoteip);  
-	saslprops.ipremoteport = xstrdup(remoteip);
+	if(iptostring((struct sockaddr *)&sync_remoteaddr, salen,
+		      remoteip, 60) == 0) {
+	    sasl_setprop(sync_saslconn, SASL_IPREMOTEPORT, remoteip);  
+	    saslprops.ipremoteport = xstrdup(remoteip);
+	}
+    } else {
+	/* we're not connected to an internet socket! */
+	strcpy(sync_clienthost, "[unix socket]");
+	sync_userid = xstrdup("cyrus");
+	sync_userisadmin = 1;
     }
 
     proc_register("sync_server", sync_clienthost, NULL, NULL);
@@ -540,7 +549,7 @@ static int reset_saslconn(sasl_conn_t **conn)
        ret = sasl_setprop(*conn, SASL_IPLOCALPORT,
                           saslprops.iplocalport);
     if(ret != SASL_OK) return ret;
-    secprops = mysasl_secprops(SASL_SEC_NOPLAINTEXT);
+    secprops = mysasl_secprops(SASL_SEC_NOANONYMOUS);
     ret = sasl_setprop(*conn, SASL_SEC_PROPS, secprops);
     if(ret != SASL_OK) return ret;
     /* end of service_main initialization excepting SSF */
@@ -1762,6 +1771,7 @@ static void cmd_upload(struct mailbox *mailbox,
     struct sync_upload_list *upload_list;
     struct sync_upload_item *item;
     struct sync_message     *message;
+    struct utimbuf settime;
     static struct buf arg;
     int   c;
     enum {MSG_SIMPLE, MSG_PARSED, MSG_COPY} msg_type;
@@ -1860,7 +1870,7 @@ static void cmd_upload(struct mailbox *mailbox,
         switch (msg_type) {
         case MSG_SIMPLE:
             if (c != ' ') {
-                err = "Invalid flags";
+                err = "Invalid flags or missing message";
                 goto parse_err;
             }
 
@@ -1878,11 +1888,16 @@ static void cmd_upload(struct mailbox *mailbox,
                 err = "Invalid Message";
                 goto parse_err;
             }
+
+            /* Set mtime of message file to be internal date */
+            settime.actime = settime.modtime = item->internaldate;
+            utime(message->msg_path, &settime);
+
             c = prot_getc(sync_in);
             break;
         case MSG_PARSED:
             if (c != ' ') {
-                err = "Invalid flags";
+                err = "Invalid flags or missing message";
                 goto parse_err;
             }
 
@@ -1912,6 +1927,10 @@ static void cmd_upload(struct mailbox *mailbox,
                 err = "Invalid Message";
                 goto parse_err;
             }
+
+            /* Set mtime of message file to be internal date */
+            settime.actime = settime.modtime = item->internaldate;
+            utime(message->msg_path, &settime);
             c = prot_getc(sync_in);
 
             break;
@@ -1932,6 +1951,7 @@ static void cmd_upload(struct mailbox *mailbox,
 	/* if we see a SP, we're trying to upload more than one message */
     } while (c == ' ');
 
+  done:
     if (c == EOF) {
         err = "Unexpected end of sync_in at end of item";
         goto parse_err;
