@@ -41,7 +41,7 @@
  * Original version written by David Carter <dpc22@cam.ac.uk>
  * Rewritten and integrated into Cyrus by Ken Murchison <ken@oceana.com>
  *
- * $Id: sync_support.c,v 1.2 2006/11/30 17:11:20 murch Exp $
+ * $Id: sync_support.c,v 1.9 2007/07/16 18:01:25 murch Exp $
  */
 
 #include <config.h>
@@ -511,6 +511,22 @@ struct sync_msgid *sync_msgid_add(struct sync_msgid_list *l,
     return(result);
 }
 
+void sync_msgid_remove(struct sync_msgid_list *l,
+		       struct message_uuid *uuid)
+{
+    int offset = message_uuid_hash(uuid, l->hash_size);
+    struct sync_msgid *msgid;
+
+    if (message_uuid_isnull(uuid)) return;
+
+    for (msgid = l->hash[offset] ; msgid ; msgid = msgid->hash_next) {
+	if (message_uuid_compare(&msgid->uuid, uuid)) {
+	    message_uuid_set_null(&msgid->uuid);
+	    return;
+	}
+    }
+}
+
 void sync_msgid_list_free(struct sync_msgid_list **lp)
 {
     struct sync_msgid_list *l = *lp;
@@ -914,9 +930,9 @@ struct sync_message *sync_message_add(struct sync_message_list *l,
     result = xzmalloc(sizeof(struct sync_message));
     message_uuid_set_null(&result->uuid);
     
-    result->msg_path = xzmalloc(5 * (MAX_MAILBOX_PATH+1) * sizeof(char));
+    result->msg_path = xzmalloc((MAX_MAILBOX_PATH+1) * sizeof(char));
     result->msg_path_end = result->msg_path +
-	5 * (MAX_MAILBOX_PATH+1) * sizeof(char);
+	(MAX_MAILBOX_PATH+1) * sizeof(char);
 
     snprintf(result->stagename, sizeof(result->stagename), "%lu.", l->count);
 
@@ -968,6 +984,15 @@ FILE *sync_message_open(struct sync_message_list *l,
     if (l->file_count == l->file_max)
         sync_message_fsync(l);
 
+    /* unlink just in case a previous crash left a file 
+     * hard linked into someone else's mailbox! */
+    if (unlink(message->msg_path) == -1 && errno != ENOENT) {
+	syslog(LOG_ERR,
+	       "sync_message_open(): failed to unlink stale file %s: %m",
+	       message->msg_path);
+	return(NULL);
+    }
+
     /* Open read/write so file can later be mmap()ed if needed */
     if ((file=fopen(message->msg_path, "w+")) == NULL) {
         syslog(LOG_ERR, "sync_message_open(): Unable to open %s: %m",
@@ -1316,6 +1341,8 @@ int sync_getsimple(struct protstream *input, struct protstream *output,
 
     message->hdr_size     = record.header_size;
     message->cache_offset = record.cache_offset;
+    message->content_lines = record.content_lines;
+    message->cache_version = record.cache_version;
     message->cache_size 
         = lseek(list->cache_fd, 0, SEEK_CUR) - record.cache_offset;
 
@@ -1356,6 +1383,27 @@ struct sync_upload_item *sync_upload_list_add(struct sync_upload_list *l)
     return(result);
 }
 
+void sync_upload_list_remove(struct sync_upload_list *l,
+			     struct sync_upload_item *i)
+{
+    struct sync_upload_item *prev, *current, *next;
+
+    prev = NULL;
+    current = l->head;
+    while (current) {
+	next = current->next;
+	if (current == i) {
+	    l->count--;
+	    free(current);
+	    if (prev) prev->next = next;
+	    else l->head = next;
+	    return;
+	}
+	prev = current;
+	current = next;
+    }
+}
+
 void sync_upload_list_free(struct sync_upload_list **lp)
 {
     struct sync_upload_list *l = *lp;
@@ -1423,16 +1471,18 @@ char *sync_sieve_get_path(char *userid, char *sieve_path, size_t psize)
     char *domain;
 
     if (config_getenum(IMAPOPT_VIRTDOMAINS) && (domain = strchr(userid, '@'))) {
-	char d = (char) dir_hash_c(domain+1);
+	char d = (char) dir_hash_c(domain+1, config_fulldirhash);
 	*domain = '\0';  /* split user@domain */
 	snprintf(sieve_path, psize, "%s%s%c/%s/%c/%s",
 		 config_getstring(IMAPOPT_SIEVEDIR),
-		 FNAME_DOMAINDIR, d, domain+1, dir_hash_c(userid), userid);
+		 FNAME_DOMAINDIR, d, domain+1,
+		 dir_hash_c(userid, config_fulldirhash), userid);
 	*domain = '@';  /* reassemble user@domain */
     }
     else {
 	snprintf(sieve_path, psize, "%s/%c/%s",
-		 config_getstring(IMAPOPT_SIEVEDIR), dir_hash_c(userid), userid);
+		 config_getstring(IMAPOPT_SIEVEDIR),
+		 dir_hash_c(userid, config_fulldirhash), userid);
     }
 
     return sieve_path;
