@@ -1,7 +1,7 @@
 /* imtest.c -- IMAP/POP3/NNTP/LMTP/SMTP/MUPDATE/MANAGESIEVE test client
  * Ken Murchison (multi-protocol implementation)
  * Tim Martin (SASL implementation)
- * $Id: imtest.c,v 1.93.2.15 2006/05/25 15:21:49 murch Exp $
+ * $Id: imtest.c,v 1.110 2006/11/30 17:11:22 murch Exp $
  *
  * Copyright (c) 1998-2003 Carnegie Mellon University.  All rights reserved.
  *
@@ -1083,7 +1083,8 @@ int auth_sasl(struct sasl_cmd_t *sasl_cmd, char *mechlist)
 
 	    /* send to server */
 	    if (sendliteral) {
-		printf("{%d+}\r\n", inbase64len);
+		printf("%s{%d+}\r\n",
+		       initial_response ? "" : "C: ", inbase64len);
 		prot_printf(pout, "{%d+}\r\n", inbase64len);
 		prot_flush(pout);
 	    }
