@@ -1,5 +1,5 @@
 /* acl.c -- routines for access control lists
- $Id: acl.c,v 1.10.4.1 2005/12/13 19:36:10 murch Exp $
+ $Id: acl.c,v 1.12 2007/01/02 17:19:49 murch Exp $
  
  * Copyright (c) 1998-2003 Carnegie Mellon University.  All rights reserved.
  *
@@ -41,6 +41,8 @@
  *
  * Author: Chris Newman
  * Start Date: 6/28/93
+ *
+ * RFC 4314 support added by Ken Murchison
  */
 
 #include <config.h>
@@ -53,26 +55,26 @@
 int cyrus_acl_strtomask(const char *str)
 {
     const char *deleteright = libcyrus_config_getstring(CYRUSOPT_DELETERIGHT);
+    long legacy_create = 0;
+    long legacy_delete = 0;
     long result = 0;
 
     while (*str) {
-	/* legacy DELETE right */
-	if (*str == *deleteright) result |= ACL_DELETEMBOX;
-
-	switch (*str++) {
+	switch (*str) {
 	    case 'l': result |= ACL_LOOKUP; break;
 	    case 'r': result |= ACL_READ; break;
 	    case 's': result |= ACL_SEEN; break;
 	    case 'w': result |= ACL_WRITE; break;
 	    case 'i': result |= ACL_INSERT; break;
 	    case 'p': result |= ACL_POST; break;
-	    case 'c': /* legacy CREATE macro */
+	    case 'c': /* legacy CREATE macro - build member rights */
+		legacy_create = ACL_CREATE; break;
 	    case 'k': result |= ACL_CREATE; break;
 	    case 'x': result |= ACL_DELETEMBOX; break;
 	    case 't': result |= ACL_DELETEMSG; break;
 	    case 'e': result |= ACL_EXPUNGE; break;
-	    case 'd': /* legacy DELETE macro */
-		result |= (ACL_DELETEMSG | ACL_EXPUNGE); break;
+	    case 'd': /* legacy DELETE macro - build member rights */
+		legacy_delete = (ACL_DELETEMSG | ACL_EXPUNGE); break;
 	    case 'a': result |= ACL_ADMIN; break;
 	    case '0': result |= ACL_USER0; break;
 	    case '1': result |= ACL_USER1; break;
@@ -85,33 +87,41 @@ int cyrus_acl_strtomask(const char *str)
 	    case '8': result |= ACL_USER8; break;
 	    case '9': result |= ACL_USER9; break;
 	}
+
+	if (*str++ == *deleteright) {
+	    switch (*deleteright) {
+	    case 'c': /* legacy CREATE macro - build member rights */
+		legacy_create |= ACL_DELETEMBOX; break;
+	    case 'd': /* legacy DELETE macro - build member rights */
+		legacy_delete |= ACL_DELETEMBOX; break;
+	    default: result |= ACL_DELETEMBOX; break;
+	    }
+	}
     }
 
+    /* If the rights string contained a legacy macro, but none of its
+       member rights, then we add all of the member rights for the macro.
+       Otherwise, we ignore the legacy macro.
+    */
+    if (!(result & legacy_create)) result |= legacy_create;
+    if (!(result & legacy_delete)) result |= legacy_delete;
+
     return (result);
 }
 
 /* convert an acl bit vector to a string
- *
- * The 'legacy' parameter is used to control whether we return
- * the legacy c/d macros when any of their member rights are set.
- * 'legacy' is enabled (1) for GETACL/LISTRIGHTS/MYRIGHTS responses
- * and disabled (0) for SETACL (when writing rights to disk).
  */
-char *cyrus_acl_masktostr(int acl, char *str, int legacy)
+char *cyrus_acl_masktostr(int acl, char *str)
 {
     char *pos = str;
-    int legacy_create = 0, legacy_delete = 0;
+    const char *deleteright = libcyrus_config_getstring(CYRUSOPT_DELETERIGHT);
+    int legacy_create = ACL_CREATE;
+    int legacy_delete = (ACL_DELETEMSG | ACL_EXPUNGE);
 
-    if (legacy) {
-	const char *deleteright = libcyrus_config_getstring(CYRUSOPT_DELETERIGHT);
-	legacy_create = ACL_CREATE;
-	legacy_delete = (ACL_DELETEMSG | ACL_EXPUNGE);
-
-	switch (*deleteright) {
-	    case 'c': legacy_create |= ACL_DELETEMBOX; break;
-	    case 'd': legacy_delete |= ACL_DELETEMBOX; break;
-	    default: /* XXX  we have backwards compatibility problems */ break;
-	}
+    switch (*deleteright) {
+    case 'c': legacy_create |= ACL_DELETEMBOX; break;
+    case 'd': legacy_delete |= ACL_DELETEMBOX; break;
+    default: /* XXX  we have backwards compatibility problems */ break;
     }
 
     if (acl & ACL_LOOKUP) *pos++ = 'l';
@@ -124,8 +134,14 @@ char *cyrus_acl_masktostr(int acl, char *str, int legacy)
     if (acl & ACL_DELETEMBOX) *pos++ = 'x';
     if (acl & ACL_DELETEMSG) *pos++ = 't';
     if (acl & ACL_EXPUNGE) *pos++ = 'e';
-    if (acl & legacy_create) *pos++ = 'c';
-    if (acl & legacy_delete) *pos++ = 'd';
+    if (acl & legacy_create) {
+	/* legacy CREATE macro member right(s) - add macro */
+	*pos++ = 'c';
+    }
+    if (acl & legacy_delete) {
+	/* legacy DELETE macro member right(s) - add macro */
+	*pos++ = 'd';
+    }
     if (acl & ACL_ADMIN) *pos++ = 'a';
     if (acl & ACL_USER0) *pos++ = '0';
     if (acl & ACL_USER1) *pos++ = '1';
