@@ -39,7 +39,7 @@
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
-/* $Id: master.c,v 1.104 2006/11/30 17:11:23 murch Exp $ */
+/* $Id: master.c,v 1.107 2007/07/16 17:15:53 murch Exp $ */
 
 #include <config.h>
 
@@ -48,7 +48,6 @@
 #include <string.h>
 #include <time.h>
 #include <sys/time.h>
-#include <grp.h>
 #include <sys/types.h>
 #include <sys/wait.h>
 #ifdef HAVE_UNISTD_H
@@ -59,7 +58,6 @@
 #endif
 #include <fcntl.h>
 #include <signal.h>
-#include <pwd.h>
 #include <sys/param.h>
 #include <sys/stat.h>
 #include <syslog.h>
@@ -110,7 +108,7 @@
 #include "service.h"
 
 #include "lock.h"
-
+#include "util.h"
 #include "xmalloc.h"
 
 #include "message_uuid_master.h"
@@ -190,45 +188,6 @@ void event_free(struct event *a)
     free(a);
 }
 
-int become_cyrus(void)
-{
-    struct passwd *p;
-    int newuid, newgid;
-    int result;
-    static int uid = 0;
-
-    if (uid) return setuid(uid);
-
-    p = getpwnam(CYRUS_USER);
-    if (p == NULL) {
-	syslog(LOG_ERR, "no entry in /etc/passwd for user %s", CYRUS_USER);
-	return -1;
-    }
-
-    /* Save these in case initgroups does a getpw*() */
-    newuid = p->pw_uid;
-    newgid = p->pw_gid;
-
-    if (initgroups(CYRUS_USER, newgid)) {
-        syslog(LOG_ERR, "unable to initialize groups for user %s: %s",
-	       CYRUS_USER, strerror(errno));
-        return -1;
-    }
-
-    if (setgid(newgid)) {
-        syslog(LOG_ERR, "unable to set group id to %d for user %s: %s",
-              newgid, CYRUS_USER, strerror(errno));
-        return -1;
-    }
-
-    result = setuid(newuid);
-
-    /* Only set static uid if successful, else future calls won't reset gid */
-    if (result == 0)
-        uid = newuid;
-    return result;
-}
-
 void get_prog(char *path, unsigned size, char *const *cmd)
 {
     if (cmd[0][0] == '/') {
@@ -1931,6 +1890,9 @@ int main(int argc, char **argv)
     init_snmp("cyrusMaster"); 
 #endif
 
+    /* have_uuid is global used in add_service. Rather awkward dependancy */
+    have_uuid = (config_getint(IMAPOPT_SYNC_MACHINEID) >= 0);
+
     masterconf_getsection("START", &add_start, NULL);
     masterconf_getsection("SERVICES", &add_service, NULL);
     masterconf_getsection("EVENTS", &add_event, NULL);
@@ -1954,12 +1916,11 @@ int main(int argc, char **argv)
 	}
     }
 
-    have_uuid = (config_getint(IMAPOPT_SYNC_MACHINEID) >= 0);
+    /* Should only call message_uuid_master_init after we are cyrus user */
     if (have_uuid && !message_uuid_master_init()) {
         syslog(LOG_ERR, "Couldn't initialise UUID subsystem");
         exit(EX_OSERR);
     }
-    
     /* init ctable janitor */
     init_janitor();
     
