@@ -40,8 +40,8 @@
  *
  */
 
-static char rcsid[] __attribute__((unused)) = 
-      "$Id: ldap.c,v 1.2.2.7 2006/04/13 18:39:44 murch Exp $";
+static char rcsid[] =
+      "$Id: ldap.c,v 1.10 2006/11/30 17:11:24 murch Exp $";
 
 #include <config.h>
 #include "ptloader.h"
@@ -1064,7 +1064,6 @@ static int ptsmodule_make_authstate_filter(
             if (vals == NULL)
                 continue;
 
-            strcpy((*newstate)->groups[i].id, "group:");
 	    int j;
 	    strcpy((*newstate)->groups[i].id, "group:");
 	    for(j =0; j < strlen(vals[i]); j++) {
